.. image:: https://github.com/beproud/bpmailer/actions/workflows/tests.yml/badge.svg
   :target: https://github.com/beproud/bpmailer/actions
   :alt: GitHub Actions

Requirements
============

* Python (3.6, 3.9)
* Celery (4.1)
* Django (2.2)

Links
=================

* `release checklist <https://github.com/beproud/bpmailer/blob/master/release_checklist.rst>`_
